:::tips
### 功能说明
<font style="color:#333333;">根据地址查询网点的详细信息</font><font style="color:#585A5A;">（详细地址、网点联系人、电话、服务时间、经纬度）</font>

:::

:::color1
### 支持情况
<font style="color:#333333;">顺丰速运、中通快递、圆通快递、申通快递、韵达快递、极兔速递、德邦快递、EMS、邮政平邮</font>

:::

# <font style="background-color:#74B602;"> </font> 接口信息
| **RequestType **<font style="color:#585A5A;">接口指令</font> | **<font style="color:#0070c0;">6002</font>** |
| :--- | :--- |
| **<font style="color:black;">批量请求</font>** | 不支持 |
| **<font style="color:black;">计费规则</font>** | 按次计费。系统层面成功即计费，包含查无结果的情况 |
| **<font style="color:black;">接口地址</font>** | <font style="color:rgb(0, 0, 0);">http://api.kdniao.com/api/dist</font> |


# <font style="background-color:#74B602;"> </font> 请求示例
```json
{
	"RequestData": "{
    "ShipperCode": "ZTO",
    "ProvinceName": "广东省",
    "CityName": "广州市",
    "AreaName": "黄埔区",
    "Address": "",
}",
	"EBusinessID": "1000001",
	"DataType": "2",
	"DataSign": "MxMjFmZDVkZThl0MWFhNTZjkTQ1MzE2NWU3ODdkY2QY=",
	"RequestType": "6002"
}
```

##  <font style="background-color:#1890FF;"> </font> 应用级参数
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(</font>****<font style="color:#FFFFFF;">字符长度</font>****<font style="color:#FFFFFF;">)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | --- | --- |
| ShipperCode | <font style="color:#585A5A;">String(20)</font> | - [x]  | [《快递公司编码》](https://www.yuque.com/kdnjishuzhichi/dfcrg1/mza2ln) |
| <font style="color:#000000;background-color:#ffffff;">ProvinceName</font> | <font style="color:#585A5A;">String(20)</font> | - [x]  | <font style="color:#000000;background-color:#ffffff;">省份</font> |
| <font style="color:#000000;background-color:#ffffff;">CityName</font> | <font style="color:#585A5A;">String(20)</font> | | <font style="color:#000000;background-color:#ffffff;">城市</font> |
| <font style="color:#000000;background-color:#ffffff;">AreaName</font> | <font style="color:#585A5A;">String(20)</font> | | <font style="color:#000000;background-color:#ffffff;">区县</font> |
| <font style="color:#000000;background-color:#ffffff;">Address</font> | <font style="color:#585A5A;">String(100)</font> | <font style="background:#F8CED3;color:#70000D">顺丰必填</font><br/><font style="background:#F8CED3;color:#70000D">极兔必填</font><br/><font style="background:#EFF0F0;color:#262626">其他不填</font> | <font style="color:#000000;background-color:#ffffff;">地址关键词</font><font style="color:#585A5A;background-color:#ffffff;">（模糊匹配）</font> |
| | | | |
| ~~<font style="color:#000000;background-color:#ffffff;">PointName</font>~~ | ~~<font style="color:#585A5A;">String(30)</font>~~ | <font style="background:#DBF1B7;color:#2A4200">方式二</font><br/><font style="background:#C0CAFC;color:#101E60">方式四</font> | ~~网点名~~    <font style="color:#ED740C;">敬请期待</font> |
| | | | |
| ~~<font style="color:#000000;background-color:#ffffff;">PointCode</font>~~ | ~~<font style="color:#585A5A;">String(30)</font>~~ | <font style="background:#C0DDFC;color:#00346B">方式三</font> | ~~网点编码~~   <font style="color:#ED740C;">敬请期待</font> |




# <font style="background-color:#52C41A;"> </font> 返回参数
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(</font>****<font style="color:#FFFFFF;">字符长度</font>****<font style="color:#FFFFFF;">)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | --- | --- |
| <font style="color:#000000;">EBusinessID</font> | <font style="color:#585A5A;">String(10)</font> | - [x]  | 用户ID |
| <font style="color:#000000;">Success</font> | <font style="color:#585A5A;">Boolean</font> | - [x]  | <font style="color:#000000;">成功与否 </font><font style="color:#585A5A;">(true/false)</font> |
| <font style="color:#000000;">ResultCode</font> | <font style="color:#585A5A;">String(5)</font> | - [x]  | <font style="color:#000000;">返回编码</font> |
| <font style="color:#000000;">Reason</font> | <font style="color:#585A5A;">String(50)</font> | - [ ]  | <font style="color:#000000;">失败原因</font> |
| <font style="color:#000000;">Count</font> | <font style="color:#585A5A;">int</font> | - [ ]  | <font style="color:#000000;">网点数量</font> |
| **<font style="color:#000000;">ServicePointInfos</font>** | <font style="color:#585A5A;">List</font> | - [ ]  | <font style="color:#000000;">网点信息</font> |


**<font style="color:#000000;">ServicePointInfos 展开项</font>**

| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型(字符长度)</font>** | **<font style="color:#FFFFFF;">是否必填</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| :--- | --- | --- | :--- |
| <font style="color:#000000;">ShipperCode</font> | <font style="color:#585A5A;">String(20)</font> | - [x] <font style="color:#ff0000;"></font> | <font style="color:#000000;">快递公司编码</font> |
| <font style="color:#000000;">ShipperName</font> | <font style="color:#585A5A;">String(20)</font> | - [x] <font style="color:#ff0000;"></font> | <font style="color:#000000;">快递公司名称</font> |
| <font style="color:#000000;">PointCode</font> | <font style="color:#585A5A;">String(20)</font> | - [ ] <font style="color:#000000;"></font> | <font style="color:#000000;">网点编码</font> |
| <font style="color:#000000;">PointName</font> | <font style="color:#585A5A;">String(100)</font> | - [x] <font style="color:#ff0000;"></font> | <font style="color:#000000;">网点名称</font> |
| <font style="color:#000000;">ProvinceName</font> | <font style="color:#585A5A;">String(20)</font> | - [x] <font style="color:#ff0000;"></font> | <font style="color:#000000;">所在省</font> |
| <font style="color:#000000;">CityName</font> | <font style="color:#585A5A;">String(20)</font> | - [x] <font style="color:#ff0000;"></font> | <font style="color:#000000;">所在市</font> |
| <font style="color:#000000;">AreaName</font> | <font style="color:#585A5A;">String(20)</font> | - [x] <font style="color:#ff0000;"></font> | <font style="color:#000000;">所在区</font> |
| <font style="color:#000000;">StreetName</font> | <font style="color:#585A5A;">String(50)</font> | - [ ]  | <font style="color:#000000;">所在街道</font> |
| <font style="color:#000000;">Address</font> | <font style="color:#585A5A;">String(100)</font> | - [x] <font style="color:#ff0000;"></font> | <font style="color:#000000;">详细地址</font> |
| <font style="color:#000000;">Contact</font> | <font style="color:#585A5A;">String(30)</font> | - [ ] <font style="color:#000000;"></font> | <font style="color:#000000;">网点联系人</font> |
| <font style="color:#000000;">Tel</font> | <font style="color:#585A5A;">String(20)</font> | - [ ] <font style="color:#000000;"></font> | <font style="color:#000000;">网点联系电话</font> |
| <font style="color:#000000;">ServiceTime</font> | <font style="color:#585A5A;">String</font> | - [ ] <font style="color:#000000;"></font> | <font style="color:#000000;">服务时间</font> |
| <font style="color:#000000;">Longitude</font> | <font style="color:#585A5A;">int</font> | - [ ] <font style="color:#000000;"></font> | <font style="color:#000000;">经度</font> |
| <font style="color:#000000;">Latitude</font> | <font style="color:#585A5A;">int</font> | - [ ] <font style="color:#000000;"></font> | <font style="color:#000000;">维度</font> |


##  <font style="background-color:#1890FF;"> </font> 返回示例
```json
{
  "ServicePointInfos" : [ {
    "ProvinceName" : "广东省",
    "AreaName" : "黄埔区",
    "ShipperName" : "中通快递",
    "Address" : "联达路6号大院4号",
    "ShipperCode" : "ZTO",
    "PointCode" : "4446365",
    "Tel" : "查件电话：020-22604790业务电话：13710232417",
    "PointName" : "广州东区",
    "CityName" : "广州市"
  }, {
    "ProvinceName" : "广东省",
    "AreaName" : "黄埔区",
    "ShipperName" : "中通快递",
    "Address" : "富南路51号",
    "ShipperCode" : "ZTO",
    "PointCode" : "4493906",
    "Tel" : "查件电话：020-22505288业务电话：020-22505288",
    "PointName" : "广州黄埔开发区",
    "CityName" : "广州市"
  }, {
    "ProvinceName" : "广东省",
    "AreaName" : "黄埔区",
    "ShipperName" : "中通快递",
    "Address" : "敬业路82号",
    "ShipperCode" : "ZTO",
    "PointCode" : "4449016",
    "Tel" : "查件电话：020-22147465业务电话：18529260292",
    "PointName" : "广州丰乐",
    "CityName" : "广州市"
  }, {
    "ProvinceName" : "广东省",
    "AreaName" : "黄埔区",
    "ShipperName" : "中通快递",
    "Address" : "广东省广州市黄浦区振兴公路中泰天境",
    "ShipperCode" : "ZTO",
    "PointCode" : "4400910",
    "Tel" : "查件电话：18665072563业务电话：18665072563",
    "PointName" : "广州九佛",
    "CityName" : "广州市"
  }, {
    "ProvinceName" : "广东省",
    "AreaName" : "黄埔区",
    "ShipperName" : "中通快递",
    "Address" : "广州市黄埔区天鹿南路1号",
    "ShipperCode" : "ZTO",
    "PointCode" : "4480523",
    "Tel" : "查件电话：020-22604815业务电话：18620024123",
    "PointName" : "广州新长龙",
    "CityName" : "广州市"
  }, {
    "ProvinceName" : "广东省",
    "AreaName" : "黄埔区",
    "ShipperName" : "中通快递",
    "Address" : "公路街12号",
    "ShipperCode" : "ZTO",
    "PointCode" : "4453503",
    "Tel" : "查件电话：020-82095002、020-88832320业务电话：18022323649",
    "PointName" : "萝岗镇区",
    "CityName" : "广州市"
  } ],
  "EBusinessID" : "1773807",
  "Count" : 6,
  "ResultCode" : "100",
  "Success" : true
}
```





```json
{
  "EBusinessID" : "1773807",
  "ResultCode" : "105",
  "Success" : false,
  "Reason" : "未查询到相关网点信息"
}
```



  


